@@ -55,6 +55,7 @@ char * findPath(const char *path, int mode, const char *name, bool /*path_relati
                 if (!access(prog, mode) && isreg(prog))
                     return newstr(prog);
 #endif
+#if 0
                 // If prog isn't executable and doesn't end with .xpm or .png, append .png and try the search
                 if (!(mode & X_OK) && 
                      (strlen(prog) + 4 < sizeof(prog)) &&
@@ -71,6 +72,7 @@ char * findPath(const char *path, int mode, const char *name, bool /*path_relati
                        return newstr(prog);
 #endif
                 }
+#endif
 
             }
         }
@@ -209,7 +211,7 @@ bool parseKey(const char *arg, KeySym *key, unsigned int *mod) {
         *key = XK_Delete;
     else if (strlen(arg) == 1 && arg[0] >= 'A' && arg[0] <= 'Z') {
         char s[2];
-        s[0] = arg[0] - 'A' + 'a';
+        s[0] = (char)(arg[0] - 'A' + 'a');
         s[1] = 0;
         *key = XStringToKeysym(s);
     } else {
