@@ -161,7 +161,7 @@ void YInputLine::paint(Graphics &g, const YRect &/*r*/) {
 
 bool YInputLine::handleKey(const XKeyEvent &key) {
     if (key.type == KeyPress) {
-        KeySym k = XKeycodeToKeysym(xapp->display(), key.keycode, 0);
+        KeySym k = XKeycodeToKeysym(xapp->display(), (KeyCode)key.keycode, 0);
 
         switch (k) {
         case XK_KP_Home:
@@ -176,7 +176,7 @@ bool YInputLine::handleKey(const XKeyEvent &key) {
         case XK_KP_Insert:
         case XK_KP_Delete:
             if (key.state & xapp->NumLockMask) {
-                k = XKeycodeToKeysym(xapp->display(), key.keycode, 1);
+                k = XKeycodeToKeysym(xapp->display(), (KeyCode)key.keycode, 1);
             }
             break;
         }
@@ -615,7 +615,7 @@ int YInputLine::nextWord(int p, bool sep) {
     int textLen = fText ? strlen(fText) : 0;
 
     while (p < textLen && (CHCLASS(fText[p]) == CHCLASS(fText[p + 1]) ||
-                           !sep && CHCLASS(fText[p])))
+                           (!sep && CHCLASS(fText[p]))))
         p++;
     if (p < textLen)
         p++;
@@ -626,7 +626,7 @@ int YInputLine::prevWord(int p, bool sep) {
     if (p > 0 && !sep)
         p--;
     while (p > 0 && (CHCLASS(fText[p]) == CHCLASS(fText[p - 1]) ||
-                     !sep && CHCLASS(fText[p])))
+                     (!sep && CHCLASS(fText[p]))))
         p--;
     return p;
 }
