@@ -289,6 +289,8 @@ public:
                            int screen_no = -1);
     int getScreenForRect(int x, int y, int width, int height);
 
+    virtual void grabKeys() {}
+
 #ifdef XINERAMA
 protected:
     int xiHeads;
@@ -317,6 +319,7 @@ extern Atom _XA_WM_CHANGE_STATE;
 extern Atom _XATOM_MWM_HINTS;
 extern Atom _XA_WM_COLORMAP_WINDOWS;
 extern Atom _XA_CLIPBOARD;
+extern Atom _XA_XEMBED_INFO;
 
 /* Xdnd */
 extern Atom XA_XdndAware;
